import typing
import collections.abc
import typing_extensions
import numpy.typing as npt

def convert_volume_to_mesh(
    execution_context: int | str | None = None, undo: bool | None = None
):
    """Convert the volume of a world to a mesh. The world's volume used to be rendered by EEVEE Legacy. Conversion is needed for it to render properly

    :type execution_context: int | str | None
    :type undo: bool | None
    """

def new(execution_context: int | str | None = None, undo: bool | None = None):
    """Create a new world Data-Block

    :type execution_context: int | str | None
    :type undo: bool | None
    """
